<?php
/**
 * Menu page Options
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

// panel
$wp_customize->add_panel( 'yummy_pro_menu_page_template_panel' , array(
	    'title'      => esc_html__( 'Menu Template','yummy-pro' ),
	    'description'=> esc_html__( 'Menu Template Options.', 'yummy-pro' ),
	    'priority'   => 130,
) );

/**************** First Menu Section ****************/
 
// first section
$wp_customize->add_section( 'yummy_pro_menu_page_first_section', array(
	'title'             => esc_html__( 'First Menu Category Section','yummy-pro' ),
	'panel'             => 'yummy_pro_menu_page_template_panel',
) );

// First Section Title
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_first_section_title]', array(
	'default'           => $options['menu_first_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_first_section_title]', array(
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_first_section',
	'type'				=> 'text'
) );

// First Section content type
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_first_section_content_type]', array(
	'default'           => $options['menu_first_section_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_first_section_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_first_section',
	'choices'			=> yummy_pro_menu_page_first_content_type(),
	'type'				=> 'select'
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_first_section_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_first_section_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 12 latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_first_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_first_section_content_category',
) ) );

// Show woo category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_first_section_content_woo_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_first_section_content_woo_category]', array(
	'label'           => esc_html__( 'Select Woo Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 12 latest products from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_first_section',
	'taxonomy'		  => 'product_cat',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_first_section_content_woo_category',
) ) );


/**************** Second Menu Section ****************/
 
// second section
$wp_customize->add_section( 'yummy_pro_menu_page_second_section', array(
	'title'             => esc_html__( 'Second Menu Category Section','yummy-pro' ),
	'panel'             => 'yummy_pro_menu_page_template_panel',
) );

// second Section Title
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_second_section_title]', array(
	'default'           => $options['menu_second_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_second_section_title]', array(
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_second_section',
	'type'				=> 'text'
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[menu_second_section_image]', array(
	'default'           => $options['menu_second_section_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[menu_second_section_image]',
		array(
		'label'       		=> esc_html__( 'Select Image for Title Background', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_menu_page_second_section',
) ) );

// second Section content type
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_second_section_content_type]', array(
	'default'           => $options['menu_second_section_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_second_section_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_second_section',
	'choices'			=> yummy_pro_menu_page_first_content_type(),
	'type'				=> 'select'
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_second_section_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_second_section_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 8 latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_second_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_second_section_content_category',
) ) );

// Show woo category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_second_section_content_woo_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_second_section_content_woo_category]', array(
	'label'           => esc_html__( 'Select Woo Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 8 latest products from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_second_section',
	'taxonomy'		  => 'product_cat',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_second_section_content_woo_category',
) ) );


/**************** third Menu Section ****************/
 
// third section
$wp_customize->add_section( 'yummy_pro_menu_page_third_section', array(
	'title'             => esc_html__( 'Third Menu Category Section','yummy-pro' ),
	'panel'             => 'yummy_pro_menu_page_template_panel',
) );

// third Section Title
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_third_section_title]', array(
	'default'           => $options['menu_third_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_third_section_title]', array(
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_third_section',
	'type'				=> 'text'
) );

// third Section sub Title
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_third_section_sub_title]', array(
	'default'           => $options['menu_third_section_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_third_section_sub_title]', array(
	'label'             => esc_html__( 'Sub Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_third_section',
	'type'				=> 'text'
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[menu_third_section_image]', array(
	'default'           => $options['menu_third_section_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[menu_third_section_image]',
		array(
		'label'       		=> esc_html__( 'Select Image for Title Background', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_menu_page_third_section',
) ) );

// third Section content type
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_third_section_content_type]', array(
	'default'           => $options['menu_third_section_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_third_section_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_third_section',
	'choices'			=> yummy_pro_menu_page_first_content_type(),
	'type'				=> 'select'
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_third_section_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_third_section_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 12 latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_third_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_third_section_content_category',
) ) );

// Show woo category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_third_section_content_woo_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_third_section_content_woo_category]', array(
	'label'           => esc_html__( 'Select Woo Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 12 latest products from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_third_section',
	'taxonomy'		  => 'product_cat',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_third_section_content_woo_category',
) ) );

/**************** Forth Menu Section ****************/
 
// forth section
$wp_customize->add_section( 'yummy_pro_menu_page_forth_section', array(
	'title'             => esc_html__( 'Fourth Menu Category Section','yummy-pro' ),
	'panel'             => 'yummy_pro_menu_page_template_panel',
) );

// forth Section Title
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_forth_section_title]', array(
	'default'           => $options['menu_forth_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_forth_section_title]', array(
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_forth_section',
	'type'				=> 'text'
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[menu_forth_section_image]', array(
	'default'           => $options['menu_forth_section_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[menu_forth_section_image]',
		array(
		'label'       		=> esc_html__( 'Select Image for Title Background', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_menu_page_forth_section',
) ) );

// forth Section content type
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_forth_section_content_type]', array(
	'default'           => $options['menu_forth_section_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[menu_forth_section_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_menu_page_forth_section',
	'choices'			=> yummy_pro_menu_page_first_content_type(),
	'type'				=> 'select'
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_forth_section_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_forth_section_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 12 latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_forth_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_forth_section_content_category',
) ) );

// Show woo category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[menu_forth_section_content_woo_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[menu_forth_section_content_woo_category]', array(
	'label'           => esc_html__( 'Select Woo Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Max 12 latest products from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_menu_page_forth_section',
	'taxonomy'		  => 'product_cat',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_is_menu_forth_section_content_woo_category',
) ) );
