<?php
/**
 * Reservation options
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

$wp_customize->add_panel( 'yummy_pro_reservation_template_panel' , array(
	    'title'      => esc_html__( 'Reservation Template','yummy-pro' ),
	    'description'=> esc_html__( 'Reservation Template Options.', 'yummy-pro' ),
	    'priority'   => 130,
) );

if( class_exists( 'rtbInit' ) ) {
	$wp_customize->add_section( 'yummy_pro_online_reservation_section', array(
		'title'             => esc_html__( 'Online Reservation','yummy-pro' ),
		'panel'             => 'yummy_pro_reservation_template_panel',
	) );

	$wp_customize->add_setting( 'yummy_pro_theme_options[online_reservation_title]', array(
		'default'           => $options['online_reservation_title'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'yummy_pro_theme_options[online_reservation_title]', array(
		'label'             => esc_html__( 'Online Reservation Title', 'yummy-pro' ),
		'section'           => 'yummy_pro_online_reservation_section',
		'type'				=> 'text'
	) );

	$wp_customize->add_setting( 'yummy_pro_theme_options[online_reservation_description]', array(
		'default'           => $options['online_reservation_description'],
		'sanitize_callback' => 'esc_textarea',
	) );
	$wp_customize->add_control( 'yummy_pro_theme_options[online_reservation_description]', array(
		'label'             => esc_html__( 'Online Reservation Description', 'yummy-pro' ),
		'section'           => 'yummy_pro_online_reservation_section',
		'type'				=> 'textarea'
	) );
}

$wp_customize->add_section( 'yummy_pro_phone_reservation_section', array(
	'title'             => esc_html__( 'Phone Reservation','yummy-pro' ),
	'panel'             => 'yummy_pro_reservation_template_panel',
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_content_type]', array(
	'default'           => $options['reservation_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_phone_reservation_section',
	'choices'			=> yummy_pro_reservation_content_type_options(),
	'type'				=> 'select',
	'priority'			=> 10,
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_page_id]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_page_id]', array(
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_phone_reservation_type_page_enable',
	'section'           => 'yummy_pro_phone_reservation_section',
	'type'				=> 'dropdown-pages',
	'priority'			=> 10,
) );

$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_post_id]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
	'validate_callback' => 'yummy_pro_validate_post_id',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_post_id]', array(
	'label'             => esc_html__( 'Input Post ID', 'yummy-pro' ),
	'active_callback' => 'yummy_pro_is_phone_reservation_type_post_enable',
	'section'           => 'yummy_pro_phone_reservation_section',
	'type'				=> 'number',
	'priority'			=> 11,
	'input_attrs'	  	=> array( 
		'min'			=> 1,
		'style'			=> 'width:100px' 
	),
) );

$wp_customize->add_section( 'yummy_pro_memory_reservation_section', array(
	'title'             => esc_html__( 'Reservation Details','yummy-pro' ),
	'panel'             => 'yummy_pro_reservation_template_panel',
) );

/**
 * Reservation Header Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_header_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[reservation_header_label]', array(
	'label'           	=> __( 'Header Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_memory_reservation_section',
	'type'            	=> 'description',
) ) );

/**
 * Reservation Header type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_header_type]', array(
	'default'           => $options['reservation_header_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_header_type]', array(
	'label'             => esc_html__( 'Header Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_memory_reservation_section',
	'choices'			=> yummy_pro_reservation_header_type_options(),
	'type'				=> 'select',
) );

/**
 * Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_header_title]', array(
	'default'           => $options['reservation_header_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_header_title]', array(
	'active_callback'	=> 'yummy_pro_reservation_header_custom',
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_memory_reservation_section',
	'type'				=> 'text',
) );

/**
 * Title link Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_header_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_header_link]', array(
	'active_callback'	=> 'yummy_pro_reservation_header_custom',
	'label'             => esc_html__( 'Title Link', 'yummy-pro' ),
	'section'           => 'yummy_pro_memory_reservation_section',
	'type'				=> 'url',
) );

/**
 * reservation image setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_header_image]', array(
	'default'           => $options['reservation_header_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image',
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[reservation_header_image]',
		array(
		'label'       		=> esc_html__( 'Select Image', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %1$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_memory_reservation_section',
		'active_callback'	=> 'yummy_pro_reservation_header_custom',
) ) );

/**
 * Reservation Header page Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_header_page]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_header_page]', array(
	'active_callback'	=> 'yummy_pro_reservation_header_page',
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'description'       => esc_html__( 'Info: Make sure selected page has featured image.', 'yummy-pro' ),
	'section'           => 'yummy_pro_memory_reservation_section',
	'type'				=> 'dropdown-pages'
) );

/**
 * Reservation hr setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[reservation_hr]',
	array(
		'section'         => 'yummy_pro_memory_reservation_section',
		'type'			  => 'hr'
) ) );

/**
 * Reservation Header Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_section_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[reservation_section_label]', array(
	'label'           	=> __( 'Section Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_memory_reservation_section',
	'type'            	=> 'description',
) ) );

/**
 * Reservation type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[memorable_reservation_type]', array(
	'default'           => $options['memorable_reservation_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[memorable_reservation_type]', array(
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_memory_reservation_section',
	'choices'			=> yummy_pro_reservation_memorable_type_options(),
	'type'				=> 'select',
) );

/**
 * Post Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_memorable_post_ids]', array(
    'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[reservation_memorable_post_ids]', array(
    'active_callback'   => 'yummy_pro_is_reservation_memorable_type_post_enable',
    'label'             => esc_html__( 'Input Post Ids', 'yummy-pro' ),
    'description'       => esc_html__( 'Max. posts allowed is 3. ie: 11, 24, 34', 'yummy-pro' ),
    'section'           => 'yummy_pro_memory_reservation_section',
    'type'              => 'text',
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[reservation_memorable_category]', array(
    'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[reservation_memorable_category]', array(
    'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
    'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
    'section'         => 'yummy_pro_memory_reservation_section',
    'type'            => 'dropdown-category',
    'active_callback' => 'yummy_pro_is_reservation_memorable_type_category_enable',
) ) );