<?php
/**
 * Theme Palace Theme Customizer.
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function yummy_pro_customize_register( $wp_customize ) {
	$options = yummy_pro_get_theme_options();

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load customize custom controls functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	//add contact us template
	require get_template_directory() . '/inc/customizer/custom-template/contact-us.php';

	//add about-us template
	require get_template_directory() . '/inc/customizer/custom-template/about-us.php';

	if ( class_exists( 'WooCommerce' ) ) :
		//add woo shop page
		require get_template_directory() . '/inc/customizer/custom-template/shop-page.php';
	endif;

	//add reservation template
	require get_template_directory() . '/inc/customizer/custom-template/reservation.php';

	//add menu template
	require get_template_directory() . '/inc/customizer/custom-template/menu-page.php';

	// Add panel for sections
	$wp_customize->add_panel( 'yummy_pro_sections_panel' , array(
	    'title'      => esc_html__( 'Sections','yummy-pro' ),
	    'description'=> esc_html__( 'Section Options.', 'yummy-pro' ),
	    'priority'   => 140,
	) );

	// slider
	require get_template_directory() . '/inc/customizer/sections/slider.php';
	
	// about
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// special item
	require get_template_directory() . '/inc/customizer/sections/special-item.php';

	// call to action
	require get_template_directory() . '/inc/customizer/sections/call-to-action.php';
	
	// recipe
	require get_template_directory() . '/inc/customizer/sections/recipe.php';

	// item menu
	require get_template_directory() . '/inc/customizer/sections/item-menu.php';

	// testimonial
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	// special day
	require get_template_directory() . '/inc/customizer/sections/special-day.php';


	// Add panel for common theme options
	$wp_customize->add_panel( 'yummy_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','yummy-pro' ),
	    'description'=> esc_html__( 'Theme Palace Theme Options.', 'yummy-pro' ),
	    'priority'   => 150,
	) );

	// theme color
	require get_template_directory() . '/inc/customizer/theme-options/theme-color.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load blog-options
	require get_template_directory() . '/inc/customizer/theme-options/blog-options.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load menu option
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load single option
	require get_template_directory() . '/inc/customizer/theme-options/single-options.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';
}
add_action( 'customize_register', 'yummy_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function yummy_pro_customize_preview_js() {
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	wp_enqueue_script( 'yummy_pro_customizer', get_template_directory_uri() . '/assets/js/customizer' .$min. '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'yummy_pro_customize_preview_js' );


if ( !function_exists( 'yummy_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Yummy Pro 1.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function yummy_pro_reset_options() {
		$options = yummy_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'yummy_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'yummy_pro_reset_options' );
