<?php 
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Yummy Pro 1.0
    */
    function yummy_pro_add_slider_section() {
        // Check if slider is enabled
        $enable_slider = apply_filters( 'yummy_pro_section_status', true, 'enable_slider' );

        if ( true !== $enable_slider ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'yummy_pro_filter_slider_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render slider section now.
        yummy_pro_render_slider_section( $section_details );
    }
endif;
add_action( 'yummy_pro_primary_content_action', 'yummy_pro_add_slider_section', 10 );


if ( ! function_exists( 'yummy_pro_get_slider_section_details' ) ) :
    /**
    * Slider section details.
    *
    * @since Yummy Pro 1.0
    * @param array $input Slider section details.
    */
    function yummy_pro_get_slider_section_details( $input ) {
        $options = yummy_pro_get_theme_options();

        // Slider type
        $slider_content_type  = $options['slider_content_type'];

        $content = array();
        switch ( $slider_content_type ) {
          	case 'demo':
                for ( $i=1; $i<=2; $i++ ) {

                    $content[$i]['img_array'] = get_template_directory_uri() . '/assets/uploads/slider-0'.$i.'.jpg';
                    $content[$i]['url']          = '#';
                    $content[$i]['title']        = esc_html__( 'Ready To Open', 'yummy-pro' );
                    $content[$i]['slider_logo']   = '<img src="'.get_template_directory_uri() . '/assets/uploads/slider-logo.png' .'" alt="'. esc_attr__( 'Slider Logo', 'yummy-pro' ).'" >';
                }    	        
          	break;        

          	case 'page':
                $ids = array();
                for ( $i = 1; $i <= $options['number_of_slider']; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'slider_page_'.$i ] ) ) {
                        $id = $options[ 'slider_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['slider_post_ids'] ) ) {
                    $ids = ( array ) $options['slider_post_ids'];
                }
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post__in'       => $ids,
                    'posts_per_page' => $options['number_of_slider'],
                );      
          	break;

          	case 'category':
    	        $cat_id = array();
                if ( ! empty( $options['slider_category'] ) ) {
                    $cat_id = $options['slider_category'];
                }
                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id =  (array)$cat_id;
                }
                $args = array(
                  'no_found_rows'  => true,
                  'cat'            => $cat_id,
                  'post_type'      => 'post',
                  'posts_per_page' => absint( $options['number_of_slider'] ),
                );
          	break;

          	default:
          	break;
        }

        if ( 'demo' != $slider_content_type ) {
            // Fetch posts.
            $posts = get_posts( $args );

            if ( ! empty( $posts ) ) {

                $i = 1;
                foreach ( $posts as $key => $post ) {
                    $page_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $page_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
                    } 
                    else {
                        $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array[0];
                    }
                    $content[ $i ]['url']         = get_permalink( $page_id );
                    $content[ $i ]['title']       = get_the_title( $page_id );
                    if ( ! empty( $options['slider_logo_image'.$i] ) ) {
                        $content[ $i ]['slider_logo'] = $options['slider_logo_image'.$i];
                    }
 
                    $i++;
                }
            }
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Slider section content details.
add_filter( 'yummy_pro_filter_slider_section_details', 'yummy_pro_get_slider_section_details' );


if ( ! function_exists( 'yummy_pro_render_slider_section' ) ) :
    /**
    * Start slider section
    *
    * @return string Slider content
    * @since Yummy Pro 1.0
    *
    */
    function yummy_pro_render_slider_section( $content_details = array() ) {
        $options                 = yummy_pro_get_theme_options();
        $slider_effect           = ( $options['slider_transition'] == 'fade' ) ? 'linear' : $options['slider_transition'];
        $enable_infinite_sliding = ( $options['enable_infinite_sliding'] ) ? 'true' : 'false';
        $slider_speed            = $options['slider_speed'];
        $enable_slider_pager     = ( $options['enable_slider_pager'] ) ? 'true' : 'false';
        $enable_slider_arrows    = ( $options['enable_slider_arrows'] ) ? 'true' : 'false';
        $enable_slider_autoplay  = ( $options['enable_slider_autoplay'] ) ? 'true' : 'false';
        $slider_fade             = ( $options['slider_transition'] == 'fade' ) ? 'true' : 'false';
        $make_slider_draggable   = ( $options['make_slider_draggable'] ) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
          return;
        }
        ?>
        <section id="main-slider" class="align-center main-featured-slider" 
        data-effect="<?php echo esc_attr( $slider_effect ); ?>"
        data-slick='{ 
        "slidesToShow": 1, "slidesToScroll": 1, 
        "infinite": <?php echo esc_attr( $enable_infinite_sliding );?>, 
        "speed": <?php echo absint( $slider_speed ); ?>, 
        "dots": <?php echo esc_attr( $enable_slider_pager ); ?>, 
        "arrows": <?php echo esc_attr( $enable_slider_arrows ); ?>, 
        "autoplay": <?php echo esc_attr( $enable_slider_autoplay ); ?>, 
        "fade": <?php echo esc_attr( $slider_fade ); ?>, 
        "draggable": <?php echo esc_attr( $make_slider_draggable ); ?>  }'>
            <?php foreach( $content_details as $content ){ ?>
            <div class="slider-item" style="background-image:url( '<?php echo esc_url( $content['img_array'] ); ?>' );">
                <div class="main-slider-contents wrapper">
                    <?php if( ( ! empty( $content['slider_logo'] ) ) && ( $options['enable_slider_logo'] ) ) {
                        if( 'demo' != $options['slider_content_type'] ) {
                            echo '<img src="'.esc_url( $content ['slider_logo'] ) .'" alt="'. esc_attr__( 'Slider Logo', 'yummy-pro' ).'" >';
                        }
                        else {
                            echo $content['slider_logo'];
                        }
                    } ?>
                    <h2><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                </div><!-- .main-slider-contents -->
            </div><!-- .slider-item -->
            <?php } ?>
        </section><!-- #main-slider --> 
    <?php }
endif;